==> haskell-comonad-5.0.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.1
id: comonad-5.0.1-EAitB0Um1u97dvApDogomX
key: comonad-5.0.1-EAitB0Um1u97dvApDogomX
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
abi: eb28d09617e540d9166689b88eb72b31
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/comonad-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/comonad-5.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/comonad-5.0.1
hs-libraries: HScomonad-5.0.1-EAitB0Um1u97dvApDogomX
depends:
    base-4.9.0.0 containers-0.5.7.1
    contravariant-1.4-BhMeiKXigEF6jqFehOEdeG
    distributive-0.5.2-4LsZjgK7w7a5vNYTgeYpWm
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.1
id: comonad-5.0.1-57iqRHH7ifDe0jWuqpsGW
key: comonad-5.0.1-57iqRHH7ifDe0jWuqpsGW
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
abi: 53bef271ede83c55e297ef275d1e36d7
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/comonad-5.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/comonad-5.0.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/comonad-5.0.1
hs-libraries: HScomonad-5.0.1-57iqRHH7ifDe0jWuqpsGW
depends:
    base-4.9.1.0 containers-0.5.7.1
    contravariant-1.4-8XNcYhxZMQPHL9Afkgrfdc
    distributive-0.5.2-C9neNKrkUkeGp7SgtQL5Xa
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
